""" Anonymous Device Client (calls Anonymous TEEM API) """

class AnonymousDeviceClient(object):
    """Anonymous Device Client Class

    Attributes
    ----------

    Methods
    -------
    """

    def __init__(self, client_info, **kwargs):
        """Class initialization

        Parameters
        ----------
        client_info : str
            client information
        **kwargs :
            optional keyword arguments

        Keyword Arguments
        -----------------
        api_key : str
            the api key to use

        Returns
        -------
        None
        """

        self.client_info = client_info
        self._api_key = kwargs.pop('api_key', None)

        self._telemetry_type = None
        self.telemetry_type_version = None

    def report(self, telemetry, **kwargs):
        """Class initialization

        Parameters
        ----------
        telemetry : dict
            telemetry record to send
        **kwargs :
            optional keyword arguments

        Keyword Arguments
        -----------------
        telemetry_type : str
            the telemetry type to use
        telemetry_type_version : str
            the telemetry type version to use

        Returns
        -------
        None
        """

        self._telemetry_type = kwargs.pop('telemetry_type', None)
        self.telemetry_type_version = kwargs.pop('telemetry_type_version', None)

        return telemetry



""" setup.py: see public setuptools docs for more detail """
import setuptools

# This should be a list of dependencies required for production use only
DEPENDENCIES = []

def get_description():
    """ Get project description """
    with open('./README.md', 'r') as readme:
        return readme.read()

setuptools.setup(
    name='f5-teem',
    version='1.0.0rc1',
    description='F5 TEEM Library',
    long_description=get_description(),
    long_description_content_type="text/markdown",
    author='F5 Ecosystems Group',
    author_email='solutionsfeedback@f5.com',
    license='Apache License 2.0',
    url="",
    packages=setuptools.find_packages(
        exclude=["test*", "tests*", "test_*", "test.*", "*.test"]
    ),
    install_requires=DEPENDENCIES,
    package_data={
        '': ['*.json', '*.yaml', '*.md', '*.rst']
    }
)



"""F5 TEEM Library

    Example -- Basic::

        from f5teem import AnonymousDeviceClient

        client_info = {
            'name': 'f5-sdk-python',
            'version': '1.0.0',
            'id': '<ID of the machine>'
        }
        telemetry_client = AnonymousDeviceClient(client_info, api_key='API KEY')
        telemetry_client.report(
            { 'foo': 'bar' },
            telemetry_type='Installation Usage',
            telemetry_type_version='1'
        )
"""
